@@ -3,13 +3,13 @@ package HTML::SiteTear;
 use 5.008;
 use strict;
 use warnings;
-use File::Basename;
+use File::Basename qw(basename fileparse);
 use File::Spec;
-use File::Path;
+use File::Path 2.0 qw(make_path);
 use File::Find;
 use Cwd;
 use Carp;
-use base qw(Class::Accessor);
+use base qw(Class::Accessor::Fast);
 __PACKAGE__->mk_accessors( qw(source_path
                              site_root_path
                              site_root_url
@@ -19,7 +19,7 @@ __PACKAGE__->mk_accessors( qw(source_path
 use HTML::SiteTear::Root;
 use HTML::SiteTear::Page;
 
-use Data::Dumper;
+# use Data::Dumper;
 
 =head1 NAME
 
@@ -27,11 +27,11 @@ HTML::SiteTear - Make a separated copy of a part of the site
 
 =head1 VERSION
 
-Version 1.44
+Version 1.46
 
 =cut
 
-our $VERSION = '1.44';
+our $VERSION = '1.46';
 
 =head1 SYMPOSIS
 
@@ -141,7 +141,7 @@ sub copy_to {
         }
     } else {
         my ($name, $dir) = fileparse($destination_path);
-        mkpath($dir);
+        make_path($dir);
         unless ($name) {
             $destination_path = File::Spec->catfile($dir,
                                                 basename($source_path));
@@ -178,23 +178,23 @@ sub copy_to_dir {
     $self->target_path($destination_path);
     my $root = HTML::SiteTear::Root->new(%$self);
     my $source_root_uri = $root->source_root_uri;
-    my $dest_uri = URI::file->new($destination_path);
-    my @results;
-    foreach my $file (@{$self->member_files}) {
-        my $a_member_file = $file;
-        unless (File::Spec->file_name_is_absolute($a_member_file)) {
-            $a_member_file = URI::file->new($a_member_file)
-                                   ->abs($self->source_path)->file;
-        }
-        my $page = HTML::SiteTear::Page->new(
-                                            'parent' => $root,
-                                            'source_path' => $a_member_file);
+    my $dest_uri = URI::file->new_abs($destination_path);
+    my @results = map {
+        my $a_member_file = do {
+            if (File::Spec->file_name_is_absolute($_)) {
+                $_;
+            }else {
+                URI::file->new($_)
+                    ->abs($self->source_path)->file;
+            }};
+        my $page = HTML::SiteTear::Page->new('parent' => $root,
+                                             'source_path' => $a_member_file);
         my $rel_from_source_root = $page->source_uri->rel($source_root_uri);
         my $abs_from_dest = $rel_from_source_root->abs($dest_uri);
         $page->link_uri($abs_from_dest);
         $page->copy_to_linkpath;
-        push @results, $page;
-    }
+        $page;
+    } @{$self->member_files};
     return \@results;
 }
 
